Crate dioxus_motion_core

Crate dioxus_motion_core 

Shared motion graph primitives for Dioxus animation packages.

This crate deliberately avoids DOM/runtime concepts. Package crates convert their existing configs into this graph, and SSR runtimes use the same shape to share scheduling, telemetry, and control semantics.

Modules

dx
prelude

Structs

BorrowedMotionTargetRef
MotionBaselineReport
MotionBatchRequest
MotionBudget
MotionCompatibilityRow
MotionDiagnostic
MotionDiagnosticVerbosity
MotionDoctorReport
MotionExplainReport
MotionGraph
MotionGroup
MotionIntegrationPolicy
MotionKeyframe
MotionManifestFragment
MotionMemoryCache
MotionOffloadPlan
MotionRouteOverride
MotionTargetRef
MotionTraceEvent
MotionTrack

Enums

MotionCurve
MotionDiagnosticLevel
MotionIntegrationTarget
MotionPlayback
MotionPolicyDecision
MotionPresetProfile
MotionReducedMotionPolicy
MotionRenderLane
MotionSerializationFormat
MotionTrackKind
MotionTrigger
MotionValidationError

Constants

DEFAULT_MOTION_DURATION_MS
DEFAULT_MOTION_STAGGER_MS
DIOXUS_MOTION_CORE_VERSION

Traits

DurationDx
MotionArtifactCache

Functions

aggressive_motion_group
apply_motion_policy_hook
balanced_motion_group
batch_motion_manifest
compact_motion_dictionary
conservative_motion_group
duration_ms_u16
duration_ms_u32
explain_motion_integration
keyframe
motion
motion_baseline_report
motion_cache_key
motion_compatibility_matrix
motion_css_custom_properties
motion_doctor
motion_group
motion_manifest_fragment
motion_manifest_fragment_with_trace
motion_target_ref_borrowed
motion_workertown_offload_plan
process_motion_batch
serialize_motion_fragment
validate_motion_graph

Type Aliases

Motion
MotionGrp
MotionKf